@@ -169,8 +169,7 @@ on_slide <- function( x, index ){
     stop("unvalid index ", index, " (", l_," slide(s))", call. = FALSE)
   }
 
-  slide_file <- x$slide$get_slide_list()
-  x$cursor = which(slide_file$slide_index == index )
+  x$cursor <- index
   x
 }
 
