@@ -58,11 +58,6 @@ test_that("id are sequentially defined", {
     doc <- body_add_img(x = doc, src = img.file, height = 1.06, width = 1.39 )
     any_img <- TRUE
   }
-  if( requireNamespace("ionicons", quietly = TRUE) ){
-    calendar_src = ionicons::as_png(name = "calendar", fill = "#FFE64D", width = 144, height = 144)
-    doc <- body_add_img(x = doc, src = calendar_src, height = 2, width = 2 )
-    any_img <- TRUE
-  }
   print(doc, target = "body_add_img.docx" )
   skip_if_not(any_img)
 
